<?php

if( !class_exists('PVTFW_PRINT_TABLE' )):

    class PVTFW_PRINT_TABLE {

        protected static $_instance = null;

        public function __construct(){
            $this->register();
        }

        public static function instance() {
            if( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
        *====================================================
        * Render Table 
        *====================================================
        **/
        function print_table(){
            global $product;
            if ($product->is_type('variable')) {  

        ?>
        <h2 id="variant-table">
            <?php echo apply_filters('pvtfw_variant_table_varaints_heading', __('Available Options', 'product-variant-table-for-woocommerce')) ?>
        </h2>

        <!-- Hook to display anything before the table -->
        <?php do_action('pvtfw_variation_table_before'); ?>
        
        <!-- Scrollable classes adding -->
        <?php 
            $scrollableTableX = PVTFW_COMMON::pvtfw_get_options()->scrollableTableX;
            if($scrollableTableX == 'on') {
                $data = ['pvt-scroll-x'];
                $classes = PVTFW_COMMON::container( $data );
            }
            else{
                $classes = "";
            }
        ?>

        <div class="pvtfw_variant_table_block <?php echo apply_filters('pvtfw_table_container_class', $classes, $scrollableTableX); ?>">
            <table class="variant">
                <thead>
                    <tr>
                        <?php 
                        $showTableHeader = PVTFW_COMMON::pvtfw_get_options()->showTableHeader;
                        if($showTableHeader == "on"):
                            /**
                             * Hook: pvtfw_table_header.
                             *
                             * @hooked pvtfw_print_table_header - 29
                             * (inc/table-parts/content-thead.php)
                             */
                            do_action('pvtfw_table_header');
                        endif;
                        ?>
                    </tr>
                </thead>
                <tbody>
                    <?php 
                        /**
                         * Hook: pvtfw_table_body.
                         *
                         * @hooked pvtfw_print_table_data - 29
                         * (inc/table-parts/content-tbody.php)
                         */
                        do_action('pvtfw_table_body');
                    ?>
                </tbody>
            </table>
        </div>

        <!-- Hook to display anything after the table -->
        <?php do_action('pvtfw_variation_table_after'); ?>
        
        <?php
            }
            else {
                wp_dequeue_script('product-variant-table-scripts');
                wp_dequeue_script('prodcut-variant-table-app-style');
            }
        }
        /**
        *====================================================
        * Render Table as shortcode
        *====================================================
        **/

        function shortcode_print_table(){

            global $product;

            ob_start();

            if ( is_a( $product, 'WC_Product' ) ) {

                if ($product->is_type('variable')) {  
        ?>
                    <h2 id="variant-table">
                        <?php echo apply_filters('pvtfw_variant_table_varaints_heading', __('Available Options', 'product-variant-table-for-woocommerce')) ?>
                    </h2>

                    <!-- Hook to display anything before the table -->
                    <?php do_action('pvtfw_variation_table_before'); ?>

                    <!-- Scrollable classes adding -->
                    <?php 
                        $scrollableTableX = PVTFW_COMMON::pvtfw_get_options()->scrollableTableX;
                        if($scrollableTableX == 'on') {
                            $data = ['pvt-scroll-x'];
                            $classes = PVTFW_COMMON::container( $data );
                        }
                        else{
                            $classes = "";
                        }
                    ?>

                    <div class="pvtfw_variant_table_block <?php echo apply_filters('pvtfw_table_container_class', $classes, $scrollableTableX); ?>">
                        <table class="variant">
                            <thead>
                                <tr>
                                    <?php 
                                    $showTableHeader = PVTFW_COMMON::pvtfw_get_options()->showTableHeader;
                                    if($showTableHeader == "on"):
                                        /**
                                         * Hook: pvtfw_table_header.
                                         *
                                         * @hooked pvtfw_print_table_header - 99
                                         * (inc/table-parts/content-thead.php)
                                         */
                                        do_action('pvtfw_table_header');
                                    endif;
                                    ?>
                                </tr>
                            </thead>
                            <tbody>
                                <?php 
                                    /**
                                     * Hook: pvtfw_table_body.
                                     *
                                     * @hooked pvtfw_print_table_data - 99
                                     * (inc/table-parts/content-tbody.php)
                                     */
                                    do_action('pvtfw_table_body');                
                                ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Hook to display anything after the table -->
                    <?php do_action('pvtfw_variation_table_after'); ?>
        
        <?php
                }
                else {
                    wp_dequeue_script('product-variant-table-scripts');
                    wp_dequeue_script('prodcut-variant-table-app-style');
                }

            }
            
            return ob_get_clean();
        }

        /**
        *====================================================
        * Allocate table
        *====================================================
        **/
        public static function allocation() {

            $place = PVTFW_COMMON::pvtfw_get_options()->table_place;
            $priority = strrchr($place, "_");
            $table['place'] = str_replace($priority, "", $place);
            $table['priority'] = str_replace("_", "", $priority);
            // add_action($place, array($this, 'print_table'), $priority);
            return $table;
        }


        /**
        *====================================================
        * Register
        *====================================================
        **/
        public function register(){
            // callback from allocaiton
            $table = self::allocation();
            add_shortcode( 'pvtfw_table_display', array( $this, 'shortcode_print_table') );
            add_action($table['place'], array($this, 'print_table'), $table['priority']);
        }

    }


    $pvtfw_print_table = PVTFW_PRINT_TABLE::instance();
    

endif;